@@ -56,7 +56,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT"
-__version__: str = "0.3.0"
+__version__: str = "0.3.1"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = [
@@ -96,7 +96,7 @@ def format_default_value(value: Any) -> Optional[str]:
 
 	:param value:
 
-	.. versionadded:: 0.3.0
+	.. versionadded:: 0.3.1
 	"""
 
 	if value is not inspect.Signature.empty and value is not Ellipsis:
@@ -151,7 +151,7 @@ def process_docstring(
 
 	if callable(obj):
 
-		if lines[-1]:
+		if not lines or lines[-1]:
 			lines.append('')
 
 		default_getter: Union[Callable[[Type], _defaults], Callable[[Callable], _defaults]]
